@@ -1,5 +1,8 @@
+skip_if_not_installed("mlr3")
+
 test_that("TreeAuditorFitters work", {
   skip_on_cran()
+  skip_if_not_installed("mlr3learners") 
   skip_if_not_installed("rpart")
   tsk = tsk("sonar")
   data = tsk$data()[, Class := as.integer(Class) - 1L]
@@ -12,4 +15,4 @@ test_that("TreeAuditorFitters work", {
   expect_list(mc$iter_models, len = 5)
   out = mc$predict_probs(d[201:208,])
   expect_numeric(out)
-})
\ No newline at end of file
+})
